@@ -45,7 +45,7 @@
 /**
  * Minor version number.
  */
-#define RAPIDSVN_VER_MINOR 10
+#define RAPIDSVN_VER_MINOR 12
 
 /**
  * Micro version number.
@@ -60,11 +60,15 @@
 /**
  * Combined version string
  */
-#define RAPIDSVN_VER_STR "0.10.0"
+#define RAPIDSVN_VER_STR "0.12.0"
+
+#ifndef RAPIDSVN_VER_REVISION
+#define RAPIDSVN_VER_REVISION 0
+#endif
 
 /* Symbolic name of the milestone
    Modify whenever Minor number is changed. */
-#define RAPIDSVN_VER_MILESTONE "0.10"
+#define RAPIDSVN_VER_MILESTONE "0.12"
 
 #endif
 /* -----------------------------------------------------------------
